@@ -4,10 +4,18 @@ describe 'aodh' do
 
   shared_examples 'aodh' do
 
+    it { is_expected.to contain_class('aodh::deps') }
+    it { is_expected.to contain_class('aodh::db') }
+    it { is_expected.to contain_class('aodh::logging') }
+
     context 'with default parameters' do
-     it 'contains the logging class' do
-       is_expected.to contain_class('aodh::logging')
-     end
+      let :params do
+        { :purge_config => false  }
+      end
+
+      it 'contains the logging class' do
+        is_expected.to contain_class('aodh::logging')
+      end
 
       it 'installs packages' do
         is_expected.to contain_package('aodh').with(
@@ -20,6 +28,8 @@ describe 'aodh' do
       it 'configures rabbit' do
         is_expected.to contain_aodh_config('DEFAULT/rpc_backend').with_value('rabbit')
         is_expected.to contain_aodh_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
         is_expected.to contain_aodh_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
@@ -32,6 +42,13 @@ describe 'aodh' do
         is_expected.to contain_aodh_config('oslo_messaging_notifications/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_aodh_config('database/alarm_history_time_to_live').with_value('<SERVICE DEFAULT>')
       end
+
+      it 'passes purge to resource' do
+        is_expected.to contain_resources('aodh_config').with({
+          :purge => false
+        })
+      end
+
     end
 
     context 'with overridden parameters' do
